@@ -36,6 +36,11 @@ class QiDataController:
         self.__bar_series_map = {}
         self.__tick_series_map = {}
 
+    def init(self, trading_date):
+        self.trading_day = trading_date
+        self.__bar_series_map.clear()
+        self.__tick_series_map.clear()
+
     def __load_today_tick_series(self, market, instrument_id, trading_date):
         path = self.__future_tick_cache_path
         tick_series = []
